# -*- coding: utf-8 -*-

# Copyright (c) 2002, 2003 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Start Program dialog.
"""

from qt import *

from StartForm import StartForm

class StartDialog(StartForm):
    """
    Class implementing the Start Program dialog.
    
    It implements a dialog that is used to start an
    application for debugging. It asks the user to enter
    the commandline parameters, the working directory and
    whether exception reporting should be disabled.
    """
    def __init__(self, argvList, wdList, exceptions, parent=None):
        """
        Constructor
        
        Arguments
        
            argvList -- history list of commandline arguments (QStringList)
            
            wdList -- history list of working directories (QStringList)
            
            exceptions -- exception reporting flag (boolean)
            
            parent -- parent widget of this dialog (QWidget)
        """
        StartForm.__init__(self, parent, None, 1)
        
        self.cmdlineCombo.clear()
        self.cmdlineCombo.insertStringList(argvList)
        if argvList.count() > 0:
            self.cmdlineCombo.setCurrentItem(0)
        self.workdirCombo.clear()
        self.workdirCombo.insertStringList(wdList)
        if wdList.count() > 0:
            self.workdirCombo.setCurrentItem(0)
        self.exceptionCheckBox.setChecked(exceptions)
        
        dummy = self.trUtf8('dummy')
        
    def handleDir(self):
        """
        Private method used to open a directory selection dialog.
        """
        cwd = self.workdirCombo.currentText()
        d = QFileDialog.getExistingDirectory(cwd,
            self, None, self.trUtf8('Working directory'))
            
        if not d.isNull() and not d.isEmpty():
            self.workdirCombo.setCurrentText(QDir.convertSeparators(d))
        
    def getData(self):
        """
        Public method to retrieve the data entered into this dialog.
        
        Returns
        
            a tuple of argv, workdir, exceptions
        """
        return (self.cmdlineCombo.currentText(),
                self.workdirCombo.currentText(),
                self.exceptionCheckBox.isChecked())
